#!/usr/bin/env node

// src/proxy.ts
import { Server } from "@modelcontextprotocol/sdk/server/index.js";
import { StdioServerTransport } from "@modelcontextprotocol/sdk/server/stdio.js";

// src/lib/utils.ts
import { SSEClientTransport } from "@modelcontextprotocol/sdk/client/sse.js";
import * as fs from "node:fs";
import * as path from "node:path";
var LOG_DIR = process.env.LOG_DIR || path.join(process.cwd(), "logs");
var LOG_FILE = process.env.LOG_FILE || path.join(LOG_DIR, "mcp-proxy.log");
if (process.env.LOG_FILE || process.env.LOG_DIR) {
  const logDir = path.dirname(LOG_FILE);
  if (!fs.existsSync(logDir)) {
    fs.mkdirSync(logDir, { recursive: true });
  }
}
function log(message, ...args) {
  const timestamp = (/* @__PURE__ */ new Date()).toISOString();
  const formattedArgs = args.length > 0 ? args.map((arg) => typeof arg === "object" ? JSON.stringify(arg) : arg).join(" ") : "";
  const logMessage = `${timestamp}: ${message}${formattedArgs ? " " + formattedArgs : ""}
`;
  if (process.env.LOG_FILE || process.env.LOG_DIR) {
    fs.appendFileSync(LOG_FILE, logMessage);
  }
}

// src/lib/wordpress-api.ts
function validateEnvironment() {
  const requiredEnvVars = ["WP_API_URL", "WP_API_USERNAME", "WP_API_PASSWORD"];
  const missingVars = requiredEnvVars.filter((varName) => !process.env[varName]);
  if (missingVars.length > 0) {
    throw new Error(
      `Missing required environment variables: ${missingVars.join(
        ", "
      )}. Please set these variables before starting the server.`
    );
  }
}
async function wpRequest(params = { method: "init" }) {
  validateEnvironment();
  const endpoint = "wp/v2/wpmcp";
  const method = "POST";
  const baseUrl = process.env.WP_API_URL;
  log(`Request method: ${params.method || "init"}`);
  log(`Request args: ${JSON.stringify(params.args || {})}`);
  let username;
  let password;
  if (params.method === "tools/call" && params.args && params.args.tool && params.args.tool.startsWith("wc_reports_")) {
    username = process.env.WOO_CUSTOMER_KEY;
    password = process.env.WOO_CUSTOMER_SECRET;
    log(`Using WooCommerce credentials for tool: ${params.args.tool}`);
    if (!username || !password) {
      throw new Error(
        "Missing WooCommerce credentials. Please set WOO_CUSTOMER_KEY and WOO_CUSTOMER_SECRET environment variables."
      );
    }
  } else {
    username = process.env.WP_API_USERNAME;
    password = process.env.WP_API_PASSWORD;
    log(`Using WordPress credentials for method: ${params.method || "init"}`);
  }
  log(`Username length: ${username ? username.length : 0}`);
  log(`Password length: ${password ? password.length : 0}`);
  log(`Environment: ${process.env.NODE_ENV || "development"}`);
  log(`API URL: ${baseUrl}`);
  const auth = Buffer.from(`${username}:${password}`).toString("base64");
  log(`Auth header length: ${auth.length}`);
  const url = new URL(`/wp-json/${endpoint}`, baseUrl).toString();
  log(`Requesting URL: ${url}`);
  const headers = {
    Authorization: `Basic ${auth}`,
    "Content-Type": "application/json"
  };
  const fetchOptions = {
    method,
    headers,
    body: JSON.stringify(params)
  };
  try {
    log(`Sending request to WordPress API...`);
    const response = await fetch(url, fetchOptions);
    log(`Response status: ${response.status}`);
    if (!response.ok) {
      const errorText = await response.text();
      log(`Error response: ${errorText}`);
      throw new Error(`WordPress API error (${response.status}): ${errorText}`);
    }
    const responseData = await response.json();
    log(`Response received successfully`);
    return responseData;
  } catch (error) {
    log(`Error in wpRequest: ${error instanceof Error ? error.message : String(error)}`);
    throw error;
  }
}

// src/proxy.ts
import {
  CallToolRequestSchema,
  ListResourcesRequestSchema,
  ListToolsRequestSchema,
  ListPromptsRequestSchema,
  GetPromptRequestSchema,
  ListResourceTemplatesRequestSchema,
  ReadResourceRequestSchema,
  SubscribeRequestSchema,
  UnsubscribeRequestSchema,
  SetLevelRequestSchema,
  CompleteRequestSchema,
  ListRootsRequestSchema
} from "@modelcontextprotocol/sdk/types.js";
async function WordPressProxy() {
  const init = await wpRequest({ method: "init" });
  const server = new Server(
    {
      name: init.serverInfo.name,
      version: init.serverInfo.version
    },
    {
      capabilities: init.capabilities
      // Type assertion to fix linter error
    }
  );
  const withLogging = (schema, handler) => async (request) => {
    log(`Received ${schema} request:`, JSON.stringify(request));
    const response = await handler(request);
    log(`${schema} response:`, JSON.stringify(response));
    return response;
  };
  server.setRequestHandler(
    ListToolsRequestSchema,
    withLogging("ListTools", async (request) => {
      log("Processing ListToolsRequest");
      const response = await wpRequest({
        method: "tools/list",
        cursor: request.params?.cursor
      });
      return response;
    })
  );
  server.setRequestHandler(
    CallToolRequestSchema,
    withLogging("CallTool", async (request) => {
      log("Processing CallToolRequest");
      const response = await wpRequest({
        method: "tools/call",
        name: request.params.name,
        arguments: request.params.arguments
      });
      return response;
    })
  );
  server.setRequestHandler(
    ListResourcesRequestSchema,
    withLogging("ListResources", async (request) => {
      log("Processing ListResourcesRequest");
      const response = await wpRequest({
        method: "resources/list",
        cursor: request.params?.cursor
      });
      return response;
    })
  );
  server.setRequestHandler(
    ListResourceTemplatesRequestSchema,
    withLogging("ListResourceTemplates", async (request) => {
      log("Processing ListResourceTemplatesRequest");
      const response = await wpRequest({
        method: "resources/templates/list",
        cursor: request.params?.cursor
      });
      return response;
    })
  );
  server.setRequestHandler(
    ReadResourceRequestSchema,
    withLogging("ReadResource", async (request) => {
      log("Processing ReadResourceRequest");
      const response = await wpRequest({
        method: "resources/read",
        uri: request.params.uri
      });
      return response;
    })
  );
  server.setRequestHandler(
    SubscribeRequestSchema,
    withLogging("Subscribe", async (request) => {
      log("Processing SubscribeRequest");
      const response = await wpRequest({
        method: "resources/subscribe",
        uri: request.params.uri
      });
      return response;
    })
  );
  server.setRequestHandler(
    UnsubscribeRequestSchema,
    withLogging("Unsubscribe", async (request) => {
      log("Processing UnsubscribeRequest");
      const response = await wpRequest({
        method: "resources/unsubscribe",
        uri: request.params.uri
      });
      return response;
    })
  );
  server.setRequestHandler(
    ListPromptsRequestSchema,
    withLogging("ListPrompts", async (request) => {
      log("Processing ListPromptsRequest");
      const response = await wpRequest({
        method: "prompts/list",
        cursor: request.params?.cursor
      });
      return response;
    })
  );
  server.setRequestHandler(
    GetPromptRequestSchema,
    withLogging("GetPrompt", async (request) => {
      log("Processing GetPromptRequest");
      const response = await wpRequest({
        method: "prompts/get",
        name: request.params.name,
        arguments: request.params.arguments
      });
      return response;
    })
  );
  server.setRequestHandler(
    SetLevelRequestSchema,
    withLogging("SetLevel", async (request) => {
      log("Processing SetLevelRequest");
      const response = await wpRequest({
        method: "logging/setLevel",
        level: request.params.level
      });
      return response;
    })
  );
  server.setRequestHandler(
    CompleteRequestSchema,
    withLogging("Complete", async (request) => {
      log("Processing CompleteRequest");
      const response = await wpRequest({
        method: "completion/complete",
        ref: request.params.ref,
        argument: request.params.argument
      });
      return response;
    })
  );
  server.setRequestHandler(
    ListRootsRequestSchema,
    withLogging("ListRoots", async (request) => {
      log("Processing ListRootsRequest");
      const response = await wpRequest({
        method: "roots/list"
      });
      return response;
    })
  );
  const transport = new StdioServerTransport();
  server.connect(transport).then(() => {
    log("MCP server connected to transport successfully");
  }).catch((error) => {
    log(`Error starting MCP server:`, error);
    process.exit(1);
  });
}
WordPressProxy();
